@@ -5,11 +5,11 @@ function(lmom) {
    if(is.null(lmom$L2))    return(TRUE)
    if(lmom$L2 <= 0)        return(FALSE)
    if(is.null(lmom$TAU3))  return(TRUE)
-   if(abs(lmom$TAU3) > 1)  return(FALSE)
+   if(abs(lmom$TAU3) >= 1) return(FALSE)
    if(is.null(lmom$TAU4))  return(TRUE)
-   if(lmom$TAU4 < (0.25*(5*lmom$TAU3^2 - 1)) | lmom$TAU4 > 1) return(FALSE)
+   if(lmom$TAU4 < (0.25*(5*lmom$TAU3^2 - 1)) || lmom$TAU4 >= 1) return(FALSE)
    if(is.null(lmom$TAU5))  return(TRUE)
-   if(lmom$TAU5 > 1)       return(FALSE)
+   if(abs(lmom$TAU5) >= 1) return(FALSE)
    return(TRUE)
-}
+} 
 
