@@ -2,7 +2,7 @@
 function(lmom) {
     para <- vector(mode="numeric", length=2)
     if(! are.lmom.valid(lmom)) {
-      warning("L-moments are invalid.")
+      warning("L-moments are invalid")
       return()
     }
     para[2] <- 2*lmom$L2
