@@ -3,7 +3,7 @@ function(lmom) {
    euler <- 0.577215664901532861
     para <- vector(mode="numeric", length=2)
    if(! are.lmom.valid(lmom)) {
-     warning("L-moments are invalid.")
+     warning("L-moments are invalid")
      return()
    } 
    para[2] <- lmom$L2/log(2) 
